@@ -46,6 +46,12 @@
 
 #define QT_FEATURE_posix_shm 1
 
+#define QT_FEATURE_pthread_clockjoin 1
+
+#define QT_FEATURE_pthread_condattr_setclock 1
+
+#define QT_FEATURE_pthread_timedjoin 1
+
 #define QT_FEATURE_qqnx_pps -1
 
 #define QT_FEATURE_renameat2 1
@@ -60,6 +66,8 @@
 
 #define QT_FEATURE_backtrace 1
 
+#define QT_FEATURE_cxx20_format 1
+
 #define QT_FEATURE_cxx23_stacktrace -1
 
 #define QT_FEATURE_cpp_winrt -1
